package controllers;

import java.util.List;

import entities.Batch;
import interfacesDAO.BatchDAO;
import jakarta.inject.Inject;
import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.DELETE;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.PUT;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.Context;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Request;
import jakarta.ws.rs.core.Response;
import jakarta.ws.rs.core.UriInfo;


@Path("/batches")
public class BatchController {
	
	@Context
	UriInfo uriInfo;

	@Context
	Request request;
	
	@Inject
	private BatchDAO batchDao;
	private String message;
	
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
	public List<Batch> getBatches() {
		return batchDao.get();
	}
	
	@GET
	@Path("/getBy/{id}")
	@Produces(MediaType.APPLICATION_JSON)
	public Response find(@PathParam("id") Integer id) {
		Batch batch = batchDao.get(id);
		if (batch != null) {
			return Response.ok().entity(batch).build();
		} else {
			message = "No se encontró el lote";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}

	@POST
	//@Path("/createUser")
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response create(Batch batch) {
		if (batch != null) { // podría validar si ya existe el usuario
			batchDao.create(batch);
			return Response.status(Response.Status.CREATED).build();
		} else {
			return Response.status(Response.Status.CONFLICT).build();
		}
	}

	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response modify(Batch batch) {
		Batch aux = batchDao.get(batch.getId());
		if (aux != null) {
			batchDao.modify(batch);
			return Response.ok().entity(batch).build();
		} else {
			return Response.status(Response.Status.NOT_FOUND).entity("[]").build();
		}
	}

	@DELETE
	@Path("{id}")
	@Produces(MediaType.TEXT_PLAIN)
	public Response delete(@PathParam("id") Integer id) {
		Batch aux = batchDao.get(id);
		if (aux != null) {
			batchDao.delete(aux);
			return Response.noContent().build();
		} else {
			message = "No existe el lote con ese id";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}

	
}
