package controllers;

import java.util.List;

import entities.Input;
import interfacesDAO.InputDAO;
import jakarta.inject.Inject;
import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.DELETE;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.PUT;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.Context;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Request;
import jakarta.ws.rs.core.Response;
import jakarta.ws.rs.core.UriInfo;

@Path("/Inputs")
public class InputController {
	
	
	@Context
	UriInfo uriInfo;

	@Context
	Request request;
	
	@Inject
	private InputDAO inputDao;
	private String message;
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
	public List<Input> getInputs() {
		return inputDao.get();
	}
	
	@GET
	@Path("/getBy/{id}")
	@Produces(MediaType.APPLICATION_JSON)
	public Response find(@PathParam("id") Integer id) {
		Input input = inputDao.get(id);
		if (input != null) {
			return Response.ok().entity(input).build();
		} else {
			message = "No se encontró el insumo";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}

	@POST
	//@Path("/createUser")
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response create(Input input) {
		if (input != null) { // podría validar si ya existe el usuario
			inputDao.create(input);
			return Response.status(Response.Status.CREATED).build();
		} else {
			return Response.status(Response.Status.CONFLICT).build();
		}
	}

	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response modify(Input input) {
		Input aux = inputDao.get(input.getId());
		if (aux != null) {
			inputDao.modify(input);
			return Response.ok().entity(input).build();
		} else {
			return Response.status(Response.Status.NOT_FOUND).entity("[]").build();
		}
	}

	@DELETE
	@Path("{id}")
	@Produces(MediaType.TEXT_PLAIN)
	public Response delete(@PathParam("id") Integer id) {
		Input aux = inputDao.get(id);
		if (aux != null) {
			inputDao.delete(aux);
			return Response.noContent().build();
		} else {
			message = "No existe el lote con ese id";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}

}
