package controllers;

import java.util.List;

import entities.Provider;
import interfacesDAO.ProviderDAO;
import jakarta.inject.Inject;
import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.DELETE;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.PUT;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.Context;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Request;
import jakarta.ws.rs.core.Response;
import jakarta.ws.rs.core.UriInfo;

@Path("/Providers")
public class ProviderController {
	
	@Context
	UriInfo uriInfo;

	@Context
	Request request;
	@Inject
	private ProviderDAO providerDao;
	private String message;
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
	public List<Provider> getProviders() {
		return providerDao.get();
	}
	
	@GET
	@Path("/getBy/{id}")
	@Produces(MediaType.APPLICATION_JSON)
	public Response find(@PathParam("id") Integer id) {
		Provider provider = providerDao.get(id);
		if (provider != null) {
			return Response.ok().entity(provider).build();
		} else {
			message = "No se encontró el proveedor";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}

	@POST
	//@Path("/createUser")
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response create(Provider provider) {
		if (provider != null) { // podría validar si ya existe el usuario
			providerDao.create(provider);
			return Response.status(Response.Status.CREATED).build();
		} else {
			return Response.status(Response.Status.CONFLICT).build();
		}
	}

	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response modify(Provider provider) {
		Provider aux = providerDao.get(provider.getId());
		if (aux != null) {
			providerDao.modify(provider);
			return Response.ok().entity(provider).build();
		} else {
			return Response.status(Response.Status.NOT_FOUND).entity("[]").build();
		}
	}

	@DELETE
	@Path("{id}")
	@Produces(MediaType.TEXT_PLAIN)
	public Response delete(@PathParam("id") Integer id) {
		Provider aux = providerDao.get(id);
		if (aux != null) {
			providerDao.delete(aux);
			return Response.noContent().build();
		} else {
			message = "No existe el proveedor con ese id";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}
}
