package controllers;

import java.util.List;

import entities.RawMaterial;
import interfacesDAO.RawMaterialDAO;
import jakarta.inject.Inject;
import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.DELETE;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.PUT;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.Context;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Request;
import jakarta.ws.rs.core.Response;
import jakarta.ws.rs.core.UriInfo;

@Path("/RawMaterials")
public class RawMaterialController {

	@Context
	UriInfo uriInfo;

	@Context
	Request request;
	
	@Inject
	private RawMaterialDAO rawmaterialDao;
	private String message;
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
	public List<RawMaterial> getProviders() {
		return rawmaterialDao.get();
	}
	
	@GET
	@Path("/getBy/{id}")
	@Produces(MediaType.APPLICATION_JSON)
	public Response find(@PathParam("id") Integer id) {
		RawMaterial rawMaterial = rawmaterialDao.get(id);
		if (rawMaterial != null) {
			return Response.ok().entity(rawMaterial).build();
		} else {
			message = "No se encontró la materia prima";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}

	@POST
	//@Path("/createUser")
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response create(RawMaterial rawMaterial) {
		if (rawMaterial != null) { // podría validar si ya existe el usuario
			rawmaterialDao.create(rawMaterial);
			return Response.status(Response.Status.CREATED).build();
		} else {
			return Response.status(Response.Status.CONFLICT).build();
		}
	}

	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response modify(RawMaterial rawMaterial) {
		RawMaterial aux = rawmaterialDao.get(rawMaterial.getId());
		if (aux != null) {
			rawmaterialDao.modify(aux);
			return Response.ok().entity(rawMaterial).build();
		} else {
			return Response.status(Response.Status.NOT_FOUND).entity("[]").build();
		}
	}

	@DELETE
	@Path("{id}")
	@Produces(MediaType.TEXT_PLAIN)
	public Response delete(@PathParam("id") Integer id) {
		RawMaterial aux = rawmaterialDao.get(id);
		if (aux != null) {
			rawmaterialDao.delete(aux);
			return Response.noContent().build();
		} else {
			message = "No existe materia prima con ese id";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}
}
