package controllers;

import java.util.List;

import entities.Recipe;
import interfacesDAO.RecipeDAO;
import jakarta.inject.Inject;
import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.DELETE;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.PUT;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.Context;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Request;
import jakarta.ws.rs.core.Response;
import jakarta.ws.rs.core.UriInfo;

@Path("/Recipes")
public class RecipeController {
	
	@Context
	UriInfo uriInfo;

	@Context
	Request request;
	
	@Inject
	private RecipeDAO recipeDao;
	private String message;
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
	public List<Recipe> getRecipe() {
		return recipeDao.get();
	}
	
	@GET
	@Path("/getBy/{id}")
	@Produces(MediaType.APPLICATION_JSON)
	public Response find(@PathParam("id") Integer id) {
		Recipe recipe = recipeDao.get(id);
		if (recipe != null) {
			return Response.ok().entity(recipe).build();
		} else {
			message = "No se encontró la receta";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}

	@POST
	//@Path("/createUser")
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response create(Recipe recipe) {
		if (recipe != null) { // podría validar si ya existe el usuario
			recipeDao.create(recipe);
			return Response.status(Response.Status.CREATED).build();
		} else {
			return Response.status(Response.Status.CONFLICT).build();
		}
	}

	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response modify(Recipe recipe) {
		Recipe aux = recipeDao.get(recipe.getId());
		if (aux != null) {
			recipeDao.modify(aux);
			return Response.ok().entity(recipe).build();
		} else {
			return Response.status(Response.Status.NOT_FOUND).entity("[]").build();
		}
	}

	@DELETE
	@Path("{id}")
	@Produces(MediaType.TEXT_PLAIN)
	public Response delete(@PathParam("id") Integer id) {
		Recipe aux = recipeDao.get(id);
		if (aux != null) {
			recipeDao.delete(aux);
			return Response.noContent().build();
		} else {
			message = "No existe receta con ese id";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}
}
