package controllers;

import java.util.List;

import entities.User;
import interfacesDAO.UserDAO;
import jakarta.inject.Inject;
import jakarta.ws.rs.Consumes;
import jakarta.ws.rs.DELETE;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.PUT;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.Context;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Request;
import jakarta.ws.rs.core.Response;
import jakarta.ws.rs.core.UriInfo;

@Path("/users")
public class UserController {

	@Context
	UriInfo uriInfo;

	@Context
	Request request;
	
	@Inject
	private UserDAO udao;
	private String message;

	@GET
	@Produces(MediaType.APPLICATION_JSON)
	public List<User> getUsuarios() {
		return udao.get();
	}

	@GET
	@Path("/getBy/{id}")
	@Produces(MediaType.APPLICATION_JSON)
	public Response find(@PathParam("id") Integer id) {
		User user = udao.get(id);
		if (user != null) {
			return Response.ok().entity(user).build();
		} else {
			message = "No se encontró el usuario";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}

	@POST
	//@Path("/createUser")
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response create(User usuario) {
		if (usuario != null) { // podría validar si ya existe el usuario
			udao.create(usuario);
			return Response.status(Response.Status.CREATED).build();
		} else {
			return Response.status(Response.Status.CONFLICT).build();
		}
	}

	@PUT
	@Produces(MediaType.APPLICATION_JSON)
	@Consumes(MediaType.APPLICATION_JSON)
	public Response modify(User usuario) {
		User aux = udao.get(usuario.getId());
		if (aux != null) {
			udao.modify(aux);			;
			return Response.ok().entity(usuario).build();
		} else {
			return Response.status(Response.Status.NOT_FOUND).entity("[]").build();
		}
	}

	@DELETE
	@Path("{id}")
	@Produces(MediaType.TEXT_PLAIN)
	public Response delete(@PathParam("id") Integer id) {
		User aux = udao.get(id);
		if (aux != null) {
			udao.delete(aux);
			return Response.noContent().build();
		} else {
			message = "No existe el usuario con ese id";
			return Response.status(Response.Status.NOT_FOUND).entity(message).build();
		}
	}

}
