package entities;

import java.util.Date;
import java.util.List;

import javax.persistence.*;

@Entity
@Table(name="BATCHES")
public class Batch {
	
	//Attributes
	@Id @GeneratedValue
	@Column(name="BATCH_ID")
	private long Id;
	
	@Column(nullable=false)
	private String name;
	
	@Column(nullable=false)
	private String category;
	
	@Column(nullable=false)
	private String unit;
	
	@Column(nullable=false)
	private int quantity;
	
	@Column(nullable=false)
	private Date expirationDate;
	
	@Column(nullable=false)
	private Date creationDate;
	
	@Column(nullable=false)
	private Date lastModificationDate;
	
	@Column(nullable=false)
	private String description;
	
	//Relations
	@ManyToMany
	@JoinTable(	name="BATCH_INGREDIENTS",
				joinColumns=@JoinColumn(name="B_ID",referencedColumnName="BATCH_ID"),
				inverseJoinColumns=@JoinColumn(name="RM_ID",referencedColumnName="RAW_MATERIAL_ID")
	)
	private List<RawMaterial> batchIngredients;
	
	@ManyToMany
	@JoinTable(	name="PACKAGING_ELEMENTS",
				joinColumns=@JoinColumn(name="B_ID",referencedColumnName="BATCH_ID"),
				inverseJoinColumns=@JoinColumn(name="I_ID",referencedColumnName="INPUT_ID")
	)
	private List<Input> batchPackagingElements;
	
	@ManyToOne(optional=true)
	@JoinColumn(name="RECIPE_ID")
	private Recipe recipe;
	
	public Batch() {
		super();
	}

	//Getters and Setters
	
	public long getId() {
		return Id;
	}

	public void setId(long id) {
		Id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getCategory() {
		return category;
	}

	public void setCategory(String category) {
		this.category = category;
	}

	public String getUnit() {
		return unit;
	}

	public void setUnit(String unit) {
		this.unit = unit;
	}

	public int getQuantity() {
		return quantity;
	}

	public void setQuantity(int quantity) {
		this.quantity = quantity;
	}

	public Date getExpiration() {
		return expirationDate;
	}

	public void setExpiration(Date expirationDate) {
		this.expirationDate = expirationDate;
	}

	public Date getCreationDate() {
		return creationDate;
	}

	public void setCreationDate(Date creationDate) {
		this.creationDate = creationDate;
	}

	public Date getLastModificationDate() {
		return lastModificationDate;
	}

	public void setLastModificationDate(Date lastModificationDate) {
		this.lastModificationDate = lastModificationDate;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public List<RawMaterial> getBatchIngredients() {
		return batchIngredients;
	}

	public void setBatchIngredients(List<RawMaterial> batchIngredients) {
		this.batchIngredients = batchIngredients;
	}

	public List<Input> getBatchPackagingElements() {
		return batchPackagingElements;
	}

	public void setBatchPackagingElements(List<Input> batchPackagingElements) {
		this.batchPackagingElements = batchPackagingElements;
	}

	public Recipe getRecipe() {
		return recipe;
	}

	public void setRecipe(Recipe recipe) {
		this.recipe = recipe;
	}

	@Override
	public String toString() {
		return "Batch [Id=" + Id + ", name=" + name + ", category=" + category + ", unit=" + unit + ", quantity="
				+ quantity + ", expirationDate=" + expirationDate + ", creationDate=" + creationDate
				+ ", lastModificationDate=" + lastModificationDate + ", description=" + description + ", recipe="
				+ recipe + "]";
	}
	
	
}
