package objectsDAO;

import java.util.List;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.EntityTransaction;
import javax.persistence.NoResultException;
import javax.persistence.Persistence;
import javax.persistence.Query;
import javax.persistence.TypedQuery;


public class GenericDAOImpl<T> extends GenericDAOAbs<T> {

	private static EntityManagerFactory emf;
	
	public static EntityManagerFactory getEmf() {
		return emf;
	}

	public static void setEmf(EntityManagerFactory emf) {
		GenericDAOImpl.emf = emf;
	}

	public GenericDAOImpl() {
		super();
		if (emf == null) {
			emf = Persistence.createEntityManagerFactory("miUP");
		}
	}

	@Override
	public void create(T entity) {
		EntityManager em = null;
		EntityTransaction etx = null;
		try{
			em = emf.createEntityManager();
			etx= em.getTransaction();
			etx.begin();
			em.persist(entity); 
			etx.commit();
		} catch(Exception e) {
			if(etx  != null && etx.isActive())
				etx.rollback();
			e.printStackTrace();
		} finally {
			if (em != null)
				em.close();
		}


	}

	@Override
	public void delete(T entity) {
		EntityManager em = null;
		EntityTransaction etx = null;
		try {
			em = emf.createEntityManager();
			etx = em.getTransaction();
			etx.begin();
				
			em.remove(em.contains(entity) ? entity : em.merge(entity));
			etx.commit();
			
		} catch(Exception e) {
			if(etx  != null && etx.isActive())
				etx.rollback();
			e.printStackTrace();
		} finally {
			if (em != null)
				em.close();
		}


	}

	@Override
	public void modify(T entity) {
		EntityManager em = null;
		EntityTransaction etx = null;
		try {
			em = emf.createEntityManager();
			etx = em.getTransaction();
			etx.begin();
			em.merge(entity);
			etx.commit();
		} catch(Exception e) {
			if(etx  != null && etx.isActive())
				etx.rollback();
			e.printStackTrace();		
		} finally {
			if (em != null)
				em.close();
		}


	}

	@Override
	public List<T> get() {
		List<T> entities = null;
		EntityManager em = null;
		try {
			em = emf.createEntityManager();
			System.out.println(classType.getClass().getSimpleName());
			String queryString = "SELECT e FROM " + classType.getClass() + " e";
			Query query = em.createQuery(queryString, classType.getClass());
			entities = query.getResultList();
		}catch(Exception e) {
            e.printStackTrace();
		}finally {
            if (em != null) {
                em.close();
            }
        }
		return entities;
	}

	//@SuppressWarnings("unchecked")
	@Override
	public T get(long id) {
		T entity = null;
		EntityManager em = null;
		try {
			em=emf.createEntityManager();
			String queryString = "SELECT e FROM " + classType.getClass() + " e WHERE e.id = :id";
			Query query = em.createQuery(queryString, classType.getClass());
		    query.setParameter("id", id);
			entity = (T) query.getSingleResult();
		} catch (NoResultException e) {
			e.printStackTrace();	
		}catch(Exception e) {
			e.printStackTrace();		
		} finally {
	    	if (em != null)
				em.close();
	    }
		return entity;
		
	}

	public static void closeEntityManagerFactory() {
		if(emf != null)
			emf.close();
	}

}
